package net.sf.saxon;

/**
 * The Version class holds the SAXON version information.
 */

public final class Version {

    private static final String VERSION = "8.7.3"; // not yet built
    private static final String BUILD = "060613"; //mmddhh
    private static final String RELEASE_DATE = "2006-06-13";
    
    // Bugs fixed since 8.7.1 release:
    //   1. 1475681 NPE in AxisExpression line 128 
    //   2. 1475633 compressed whitespace in PTree - affects
    //         PTreeReader
    //         PTreeWriter
    //         WhitespaceTextImpl
    //   -- build 042418 stops here
    //   3. 1476265 duplicate anonymous type names - affects SchemaElement
    //   4. 1476446 cycle in expression tree - affects
    //         SortExpression
    //         FixedSortKeyDefinition
    //   5. 1477110 overriding a required param - affects XSLParam
    //   6. 1477285 adjacent text nodes not merged - affects
    //         WhitespaceTextImpl
    //         TinyTextImpl
    //   7. 1482202 reset() in XPathEvaluator
    //   8. 1483350 DomWriter setAttributeNS
    //   9. 1486588 TypeHierarchy synchronization
    //  10. 1486803 IndexedClosure
    //  --- build 8.7.2.3 (051123) stops here
    //  11. 1491439 cast to xs:long
    //  12. 1491444 NPE with invalid key name
    //  13. 1491463 ArrayIndexOutOfBounds with preceding-sibling
    //  14. 1501549 NPE with xsl:copy-of copying an attribute - affects CopyOf
    //  15. 1500801 ClassCastException with DOM4J
    //  16. 1500857 NaN ne NaN is false - affects ValueComparison
    //  17. 1500976 GYear etc don't accept whitespace
    //  18. 1500907 hexBinary doesn't accept whitespace
    //  19. 1503612 use-when ignored on unknown XSLT element
    //  20. 1503696 dateTime(date, time) with user-defined types
    //  21. 1503699 component extraction with user-defined types
    //  22. 1504790 corrupt values of sequence variables
    //  23. 1505250 document-uri() not set using .NET API 
    //  --- build 8.7.3 (060613) stops here (not yet built)       

    private Version() {
        // class is never instantiated
    }

    /**
     * Return the name of this product. Supports the XSLT 2.0 system property xsl:product-name
     * @return the string "SAXON"
     */


    public static final String getProductName() {
        return "SAXON";
    }

   /**
     * Get the version number of the schema-aware version of the product
     * @return the version number of this version of Saxon, as a string
     */

   public static final String getSchemaAwareProductVersion() {
        return "SA " + getProductVersion();
    }

    /**
     * Get the version number of this version of the product
     * @return the version number of this version of Saxon, as a string
     */

    public static final String getProductVersion() {
        return VERSION;
    }

    /**
     * Get the issue date of this version of the product
     * @return the release date, as an ISO 8601 string
     */

    public static final String getReleaseDate() {
        return RELEASE_DATE;
    }

    /**
     * Get the version of the XSLT specification that this product supports
     * @return the string 2.0
     */

    public static final String getXSLVersionString() {
        return "2.0";
    }

    /**
     * Get a message used to identify this product when a transformation is run using the -t option
     * @return A string containing both the product name and the product
     *     version
     */

    public static final String getProductTitle() {
        return getProductName() + ' ' + getProductVersion() + " from Saxonica";
    }

    /**
     * Return a web site address containing information about the product. Supports the XSLT system property xsl:vendor-url
     * @return the string "http://saxon.sf.net/"
     */

    public static final String getWebSiteAddress() {
        return "http://www.saxonica.com/";
    }

    /**
     * Invoking net.sf.saxon.Version from the command line outputs the build number
     * @param args not used
     */
    public static void main(String[] args) {
        System.err.println(getProductTitle() + " (build " + BUILD + ')');
    }
}



//
// The contents of this file are subject to the Mozilla Public License Version 1.0 (the "License");
// you may not use this file except in compliance with the License. You may obtain a copy of the
// License at http://www.mozilla.org/MPL/
//
// Software distributed under the License is distributed on an "AS IS" basis,
// WITHOUT WARRANTY OF ANY KIND, either express or implied.
// See the License for the specific language governing rights and limitations under the License.
//
// The Original Code is: all this file.
//
// The Initial Developer of the Original Code is Michael H. Kay.
//
// Portions created by (your name) are Copyright (C) (your legal entity). All Rights Reserved.
//
// Contributor(s): none.
//
